@@ -65,5 +65,5 @@ void BcdTo7S::voltChanged()
     LogicComponent::updateOutEnabled();
     BcdBase::voltChanged();
     m_nextOutVal = m_digit;
-    sheduleOutPuts( this );
+    scheduleOutPuts( this );
 }
