@@ -35,10 +35,10 @@ class MAINMODULE_EXPORT SubCircuit : public Chip
         void loadSubCircuit( QString file );
 
         virtual Pin* addPin( QString id, QString type, QString label,
-                            int pos, int xpos, int ypos, int angle, int length=8 ) override;
+                            int pos, int xpos, int ypos, int angle, int length=8, int space=0 ) override;
 
         virtual Pin* updatePin( QString id, QString type, QString label,
-                                int xpos, int ypos, int angle, int length=8  ) override;
+                                int xpos, int ypos, int angle, int length=8, int space=0 ) override;
 
         QHash<QString, Component*> m_mainComponents;
         static QString m_subcDir;      // Subcircuit Path
